@@ -6,7 +6,7 @@ from curl2swift.generate_output import generate_ouput
 import curl2swift.utils.logger as logger
 
 
-def main():
+def main(user_input=None, is_windowed=True, should_make_request=False):
     if len(sys.argv) == 1:
         from curl2swift.layers.presentation.application import Application
 
@@ -14,7 +14,7 @@ def main():
 
     logger.setup()
     handle_options()
-    generate_ouput(should_make_request=True)
+    return generate_ouput(user_input, is_windowed=is_windowed, should_make_request=should_make_request)
 
 
 if __name__ == "__main__":
